@@ -42,12 +42,12 @@ class Marco:
         '''
 
         print('''corriendo estado actual de todas las variables constructoras...\n
-self.metadata = {}
-self.codigos = {}
-self.formato = {}
-self.fechaini = {}
-self.fechafin = {}
-self.idioma = {}
+objeto.metadata = {}
+objeto.codigos = {}
+objeto.formato = {}
+objeto.fechaini = {}
+objeto.fechafin = {}
+objeto.idioma = {}
 '''.format('<vacio>' if len(self.metadata)==0 else str(type(self.metadata))+' size: '+str(self.metadata.shape),
         self.codigos,
         self.formato,
@@ -179,8 +179,11 @@ self.idioma = {}
         filename : str (opcional)
             Nombre para guardar la informacion de la modificada self.metadata como un archivo .csv 
         '''
-                
-        df=self.metadata
+
+        self.get_metadata() if len(self.metadata) == 0 else None
+    
+        df= self.metadata
+
         indices = [ df.index[df.iloc[:,0] == k].tolist()[0] for k in self.codigos ]
         
         self.metadata = self.metadata.loc[indices]
@@ -214,10 +217,15 @@ self.idioma = {}
         header = [k['name'] for k in dict['config']['series'] ]
         df = pandas.DataFrame(columns=header) # Note that there are now row data inserted.
 
+
         for j in dict['periods']:
             # print(j['values'])
             df.loc[j['name']] = [float(ij) if ij!='n.d.' else None for ij in j['values'] ]
 
+
+        df.index = pandas.to_datetime(df.index)     #convert dates to datetime (this to zoom in and out the xlabel)
+
+
         if filename:
             df.to_csv(filename,sep=",")
         
@@ -238,10 +246,10 @@ self.idioma = {}
         titlesize : str
             Tamaño de titulo para grafica
         '''
-        plt.style.use("seaborn-pastel")
+        plt.style.use("seaborn")
 
         plt.title(title, fontsize=titlesize)
-        plt.grid(axis='y')
+        plt.grid(axis='x')
         eval('plt.{}(data)'.format(func))
-        plt.xticks(data.index, rotation =60)
+        # plt.xticks(data.index, rotation =60)
         plt.tight_layout()
